searchData={"content_type":"text/markdown","items":[{"doc":"A comprehensive Elixir client for PostHog's analytics and feature flag APIs.\n\nThis module provides a high-level interface to PostHog's APIs, allowing you to:\n- Track user events and actions\n- Manage and evaluate feature flags\n- Handle multivariate testing\n- Process events in batch\n- Work with user, group, and person properties","ref":"Posthog.html","title":"Posthog","type":"module"},{"doc":"Add your PostHog configuration to your application config:\n\n    config :posthog,\n      api_url: \"https://app.posthog.com\",  # Or your self-hosted instance\n      api_key: \"phc_your_project_api_key\"\n\nOptional configuration:\n\n    config :posthog,\n      json_library: Jason,  # Default JSON parser (optional)\n      version: 3           # API version (optional, defaults to 3)","ref":"Posthog.html#module-configuration","title":"Configuration - Posthog","type":"module"},{"doc":"Events can be tracked with various levels of detail:\n\n    # Basic event\n    Posthog.capture(\"page_view\", distinct_id: \"user_123\")\n\n    # Event with properties\n    Posthog.capture(\"purchase\", [\n      distinct_id: \"user_123\",\n      properties: %{\n        product_id: \"prod_123\",\n        price: 99.99\n      }\n    ])\n\n    # Event with custom timestamp\n    Posthog.capture(\"signup\", [distinct_id: \"user_123\"], DateTime.utc_now())\n\n    # Event with custom headers (e.g., for IP forwarding)\n    Posthog.capture(\"login\", [distinct_id: \"user_123\"],\n      [headers: [{\"x-forwarded-for\", \"127.0.0.1\"}]])","ref":"Posthog.html#module-event-tracking","title":"Event Tracking - Posthog","type":"module"},{"doc":"PostHog feature flags can be used for feature management and A/B testing:\n\n    # Get all feature flags for a user\n    {:ok, flags} = Posthog.feature_flags(\"user_123\")\n\n    # Check specific feature flag\n    {:ok, flag} = Posthog.feature_flag(\"new-dashboard\", \"user_123\")\n\n    # Quick boolean check\n    if Posthog.feature_flag_enabled?(\"new-feature\", \"user_123\") do\n      # Show new feature\n    end\n\n    # Feature flags with group/person properties\n    Posthog.feature_flags(\"user_123\",\n      groups: %{company: \"company_123\"},\n      group_properties: %{company: %{industry: \"tech\"}},\n      person_properties: %{email: \"user@example.com\"}\n    )","ref":"Posthog.html#module-feature-flags","title":"Feature Flags - Posthog","type":"module"},{"doc":"Multiple events can be sent in a single request for better performance:\n\n    events = [\n      {\"page_view\", [distinct_id: \"user_123\"], nil},\n      {\"button_click\", [distinct_id: \"user_123\", properties: %{button: \"signup\"}], nil}\n    ]\n\n    Posthog.batch(events)\n\nEach event in the batch is a tuple of `{event_name, properties, timestamp}`.","ref":"Posthog.html#module-batch-processing","title":"Batch Processing - Posthog","type":"module"},{"doc":"Sends multiple events to PostHog in a single request.","ref":"Posthog.html#batch/2","title":"Posthog.batch/2","type":"function"},{"doc":"* `events` - List of event tuples in the format `{event_name, properties, timestamp}`\n  * `opts` - Optional parameters for the batch request","ref":"Posthog.html#batch/2-parameters","title":"Parameters - Posthog.batch/2","type":"function"},{"doc":"events = [\n      {\"page_view\", [distinct_id: \"user_123\"], nil},\n      {\"button_click\", [distinct_id: \"user_123\", properties: %{button: \"signup\"}], nil}\n    ]\n\n    Posthog.batch(events)","ref":"Posthog.html#batch/2-examples","title":"Examples - Posthog.batch/2","type":"function"},{"doc":"Captures an event in PostHog.","ref":"Posthog.html#capture/3","title":"Posthog.capture/3","type":"function"},{"doc":"* `event` - The name of the event (string or atom)\n  * `params` - Required parameters including `:distinct_id` and optional properties\n  * `opts` - Optional parameters that can be either a timestamp or a keyword list of options","ref":"Posthog.html#capture/3-parameters","title":"Parameters - Posthog.capture/3","type":"function"},{"doc":"* `:headers` - Additional HTTP headers for the request\n  * `:groups` - Group properties for the event\n  * `:group_properties` - Additional properties for groups\n  * `:person_properties` - Properties for the person\n  * `:timestamp` - Custom timestamp for the event","ref":"Posthog.html#capture/3-options","title":"Options - Posthog.capture/3","type":"function"},{"doc":"# Basic event\n    Posthog.capture(\"page_view\", distinct_id: \"user_123\")\n\n    # Event with properties\n    Posthog.capture(\"purchase\", [\n      distinct_id: \"user_123\",\n      properties: %{\n        product_id: \"prod_123\",\n        price: 99.99\n      }\n    ])\n\n    # Event with timestamp\n    Posthog.capture(\"signup\", [distinct_id: \"user_123\"], DateTime.utc_now())\n\n    # Event with custom headers\n    Posthog.capture(\"login\", [distinct_id: \"user_123\"],\n      [headers: [{\"x-forwarded-for\", \"127.0.0.1\"}]])","ref":"Posthog.html#capture/3-examples","title":"Examples - Posthog.capture/3","type":"function"},{"doc":"Retrieves information about a specific feature flag for a given distinct ID.","ref":"Posthog.html#feature_flag/3","title":"Posthog.feature_flag/3","type":"function"},{"doc":"* `flag` - The name of the feature flag\n  * `distinct_id` - The unique identifier for the user\n  * `opts` - Optional parameters for the feature flag request","ref":"Posthog.html#feature_flag/3-parameters","title":"Parameters - Posthog.feature_flag/3","type":"function"},{"doc":"# Boolean feature flag\n    {:ok, flag} = Posthog.feature_flag(\"new-dashboard\", \"user_123\")\n    # Returns: %Posthog.FeatureFlag{name: \"new-dashboard\", value: true, enabled: true}\n\n    # Multivariate feature flag\n    {:ok, flag} = Posthog.feature_flag(\"pricing-test\", \"user_123\")\n    # Returns: %Posthog.FeatureFlag{\n    #   name: \"pricing-test\",\n    #   value: %{\"price\" => 99, \"period\" => \"monthly\"},\n    #   enabled: \"variant-a\"\n    # }","ref":"Posthog.html#feature_flag/3-examples","title":"Examples - Posthog.feature_flag/3","type":"function"},{"doc":"Checks if a feature flag is enabled for a given distinct ID.\n\nThis is a convenience function that returns a boolean instead of a result tuple.\nFor multivariate flags, returns true if the flag has any value set.","ref":"Posthog.html#feature_flag_enabled?/3","title":"Posthog.feature_flag_enabled?/3","type":"function"},{"doc":"* `flag` - The name of the feature flag\n  * `distinct_id` - The unique identifier for the user\n  * `opts` - Optional parameters for the feature flag request","ref":"Posthog.html#feature_flag_enabled?/3-parameters","title":"Parameters - Posthog.feature_flag_enabled?/3","type":"function"},{"doc":"if Posthog.feature_flag_enabled?(\"new-dashboard\", \"user_123\") do\n      # Show new dashboard\n    end","ref":"Posthog.html#feature_flag_enabled?/3-examples","title":"Examples - Posthog.feature_flag_enabled?/3","type":"function"},{"doc":"Retrieves all feature flags for a given distinct ID.","ref":"Posthog.html#feature_flags/2","title":"Posthog.feature_flags/2","type":"function"},{"doc":"* `distinct_id` - The unique identifier for the user\n  * `opts` - Optional parameters for the feature flag request","ref":"Posthog.html#feature_flags/2-parameters","title":"Parameters - Posthog.feature_flags/2","type":"function"},{"doc":"* `:groups` - Group properties for feature flag evaluation\n  * `:group_properties` - Additional properties for groups\n  * `:person_properties` - Properties for the person","ref":"Posthog.html#feature_flags/2-options","title":"Options - Posthog.feature_flags/2","type":"function"},{"doc":"# Basic feature flags request\n    {:ok, flags} = Posthog.feature_flags(\"user_123\")\n\n    # With group properties\n    {:ok, flags} = Posthog.feature_flags(\"user_123\",\n      groups: %{company: \"company_123\"},\n      group_properties: %{company: %{industry: \"tech\"}}\n    )","ref":"Posthog.html#feature_flags/2-examples","title":"Examples - Posthog.feature_flags/2","type":"function"},{"doc":"Low-level HTTP client for interacting with PostHog's API.\n\nThis module handles the direct HTTP communication with PostHog's API endpoints.\nIt provides functions for:\n- Sending event capture requests\n- Processing batch events\n- Retrieving feature flag information\n\nWhile this module can be used directly, it's recommended to use the higher-level\nfunctions in the `Posthog` module instead.","ref":"Posthog.Client.html","title":"Posthog.Client","type":"module"},{"doc":"The client uses the following configuration from your application:\n\n    config :posthog,\n      api_url: \"https://app.posthog.com\",  # Required\n      api_key: \"phc_your_project_api_key\", # Required\n      json_library: Jason,                 # Optional (default: Jason)\n      version: 3                          # Optional (default: 3)","ref":"Posthog.Client.html#module-configuration","title":"Configuration - Posthog.Client","type":"module"},{"doc":"The client interacts with the following PostHog API endpoints:\n- `/capture` - For sending individual and batch events\n- `/decide` - For retrieving feature flag information","ref":"Posthog.Client.html#module-api-endpoints","title":"API Endpoints - Posthog.Client","type":"module"},{"doc":"All functions return a result tuple:\n- `{:ok, response}` for successful requests\n- `{:error, response}` for failed requests with a response\n- `{:error, term()}` for other errors (network issues, etc.)","ref":"Posthog.Client.html#module-error-handling","title":"Error Handling - Posthog.Client","type":"module"},{"doc":"# Capture an event\n    Posthog.Client.capture(\"page_view\", %{distinct_id: \"user_123\"})\n\n    # Send batch events\n    events = [\n      {\"page_view\", %{distinct_id: \"user_123\"}, nil},\n      {\"click\", %{distinct_id: \"user_123\"}, DateTime.utc_now()}\n    ]\n    Posthog.Client.batch(events)\n\n    # Get feature flags\n    Posthog.Client.feature_flags(\"user_123\", groups: %{team: \"engineering\"})","ref":"Posthog.Client.html#module-examples","title":"Examples - Posthog.Client","type":"module"},{"doc":"Sends multiple events to PostHog in a single request.","ref":"Posthog.Client.html#batch/2","title":"Posthog.Client.batch/2","type":"function"},{"doc":"* `events` - List of event tuples in the format `{event_name, properties, timestamp}`\n  * `opts` - Additional options (see `t:opts/0`)\n  * `headers` - Additional HTTP headers","ref":"Posthog.Client.html#batch/2-parameters","title":"Parameters - Posthog.Client.batch/2","type":"function"},{"doc":"events = [\n      {\"page_view\", %{distinct_id: \"user_123\"}, nil},\n      {\"click\", %{distinct_id: \"user_123\", properties: %{button: \"signup\"}}, DateTime.utc_now()}\n    ]\n\n    Posthog.Client.batch(events)","ref":"Posthog.Client.html#batch/2-examples","title":"Examples - Posthog.Client.batch/2","type":"function"},{"doc":"","ref":"Posthog.Client.html#batch/3","title":"Posthog.Client.batch/3","type":"function"},{"doc":"Builds an event payload for the PostHog API.","ref":"Posthog.Client.html#build_event/3","title":"Posthog.Client.build_event/3","type":"function"},{"doc":"* `event` - The name of the event\n  * `properties` - Event properties\n  * `timestamp` - Optional timestamp for the event","ref":"Posthog.Client.html#build_event/3-parameters","title":"Parameters - Posthog.Client.build_event/3","type":"function"},{"doc":"build_event(\"page_view\", %{distinct_id: \"user_123\"}, nil)\n    build_event(\"purchase\", %{distinct_id: \"user_123\", price: 99.99}, DateTime.utc_now())","ref":"Posthog.Client.html#build_event/3-examples","title":"Examples - Posthog.Client.build_event/3","type":"function"},{"doc":"Captures a single event in PostHog.","ref":"Posthog.Client.html#capture/3","title":"Posthog.Client.capture/3","type":"function"},{"doc":"* `event` - The name of the event (string or atom)\n  * `params` - Event properties including `:distinct_id`\n  * `opts` - Additional options (see `t:opts/0`)","ref":"Posthog.Client.html#capture/3-parameters","title":"Parameters - Posthog.Client.capture/3","type":"function"},{"doc":"# Basic event\n    Posthog.Client.capture(\"page_view\", %{distinct_id: \"user_123\"})\n\n    # Event with properties and timestamp\n    Posthog.Client.capture(\"purchase\",\n      %{\n        distinct_id: \"user_123\",\n        properties: %{product_id: \"123\", price: 99.99}\n      },\n      timestamp: DateTime.utc_now()\n    )\n\n    # Event with custom headers\n    Posthog.Client.capture(\"login\",\n      %{distinct_id: \"user_123\"},\n      headers: [{\"x-forwarded-for\", \"127.0.0.1\"}]\n    )","ref":"Posthog.Client.html#capture/3-examples","title":"Examples - Posthog.Client.capture/3","type":"function"},{"doc":"Retrieves feature flags for a given distinct ID.","ref":"Posthog.Client.html#feature_flags/2","title":"Posthog.Client.feature_flags/2","type":"function"},{"doc":"* `distinct_id` - The unique identifier for the user\n  * `opts` - Additional options (see `t:opts/0`)","ref":"Posthog.Client.html#feature_flags/2-parameters","title":"Parameters - Posthog.Client.feature_flags/2","type":"function"},{"doc":"# Basic feature flags request\n    Posthog.Client.feature_flags(\"user_123\")\n\n    # With group properties\n    Posthog.Client.feature_flags(\"user_123\",\n      groups: %{company: \"company_123\"},\n      group_properties: %{company: %{industry: \"tech\"}}\n    )","ref":"Posthog.Client.html#feature_flags/2-examples","title":"Examples - Posthog.Client.feature_flags/2","type":"function"},{"doc":"Event name, can be either an atom or a binary string.","ref":"Posthog.Client.html#t:event/0","title":"Posthog.Client.event/0","type":"type"},{"doc":"HTTP headers in the format expected by :hackney.","ref":"Posthog.Client.html#t:headers/0","title":"Posthog.Client.headers/0","type":"type"},{"doc":"Options that can be passed to API requests.\n\n* `:headers` - Additional HTTP headers to include in the request\n* `:groups` - Group properties for feature flag evaluation\n* `:group_properties` - Additional properties for groups\n* `:person_properties` - Properties for the person\n* `:timestamp` - Custom timestamp for events","ref":"Posthog.Client.html#t:opts/0","title":"Posthog.Client.opts/0","type":"type"},{"doc":"Properties that can be attached to events or feature flag requests.","ref":"Posthog.Client.html#t:properties/0","title":"Posthog.Client.properties/0","type":"type"},{"doc":"Response from the PostHog API.\nContains the status code, headers, and parsed JSON body (if any).","ref":"Posthog.Client.html#t:response/0","title":"Posthog.Client.response/0","type":"type"},{"doc":"Timestamp for events. Can be a DateTime, NaiveDateTime, or ISO8601 string.","ref":"Posthog.Client.html#t:timestamp/0","title":"Posthog.Client.timestamp/0","type":"type"},{"doc":"Represents a PostHog feature flag with its evaluation state.\n\nThis module provides a struct and helper functions for working with PostHog feature flags.\nFeature flags can be either boolean (on/off) or multivariate (multiple variants).","ref":"Posthog.FeatureFlag.html","title":"Posthog.FeatureFlag","type":"module"},{"doc":"The `FeatureFlag` struct contains:\n  * `name` - The name of the feature flag\n  * `value` - The payload value associated with the flag (can be any term)\n  * `enabled` - The evaluation result (boolean for on/off flags, string for multivariate flags)","ref":"Posthog.FeatureFlag.html#module-structure","title":"Structure - Posthog.FeatureFlag","type":"module"},{"doc":"# Boolean feature flag\n    %Posthog.FeatureFlag{\n      name: \"new-dashboard\",\n      value: true,\n      enabled: true\n    }\n\n    # Multivariate feature flag\n    %Posthog.FeatureFlag{\n      name: \"pricing-test\",\n      value: %{\"price\" => 99, \"period\" => \"monthly\"},\n      enabled: \"variant-a\"\n    }","ref":"Posthog.FeatureFlag.html#module-examples","title":"Examples - Posthog.FeatureFlag","type":"module"},{"doc":"Checks if a feature flag is a boolean flag.\n\nReturns `true` if the flag is a boolean (on/off) flag, `false` if it's a multivariate flag.","ref":"Posthog.FeatureFlag.html#boolean?/1","title":"Posthog.FeatureFlag.boolean?/1","type":"function"},{"doc":"flag = Posthog.FeatureFlag.new(\"new-dashboard\", true, true)\n    Posthog.FeatureFlag.boolean?(flag)\n    # Returns: true\n\n    flag = Posthog.FeatureFlag.new(\"pricing-test\", \"variant-a\", %{})\n    Posthog.FeatureFlag.boolean?(flag)\n    # Returns: false","ref":"Posthog.FeatureFlag.html#boolean?/1-examples","title":"Examples - Posthog.FeatureFlag.boolean?/1","type":"function"},{"doc":"Creates a new FeatureFlag struct.","ref":"Posthog.FeatureFlag.html#new/3","title":"Posthog.FeatureFlag.new/3","type":"function"},{"doc":"* `name` - The name of the feature flag\n  * `enabled` - The evaluation result (boolean or string)\n  * `value` - The payload value associated with the flag","ref":"Posthog.FeatureFlag.html#new/3-parameters","title":"Parameters - Posthog.FeatureFlag.new/3","type":"function"},{"doc":"# Create a boolean feature flag\n    Posthog.FeatureFlag.new(\"new-dashboard\", true, true)\n\n    # Create a multivariate feature flag\n    Posthog.FeatureFlag.new(\"pricing-test\", \"variant-a\",\n      %{\"price\" => 99, \"period\" => \"monthly\"})","ref":"Posthog.FeatureFlag.html#new/3-examples","title":"Examples - Posthog.FeatureFlag.new/3","type":"function"},{"doc":"The response format from PostHog's feature flag API.\nContains both the flag states and their associated payloads.","ref":"Posthog.FeatureFlag.html#t:flag_response/0","title":"Posthog.FeatureFlag.flag_response/0","type":"type"},{"doc":"A map of properties that can be associated with a feature flag.","ref":"Posthog.FeatureFlag.html#t:properties/0","title":"Posthog.FeatureFlag.properties/0","type":"type"},{"doc":"The FeatureFlag struct type.\n\nFields:\n  * `name` - The name of the feature flag (string)\n  * `value` - The payload value associated with the flag (any term)\n  * `enabled` - The evaluation result (boolean or string)","ref":"Posthog.FeatureFlag.html#t:t/0","title":"Posthog.FeatureFlag.t/0","type":"type"},{"doc":"Represents the enabled state of a feature flag.\nCan be either a boolean for on/off flags or a string for multivariate flags.","ref":"Posthog.FeatureFlag.html#t:variant/0","title":"Posthog.FeatureFlag.variant/0","type":"type"}],"producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}